api.sensors.v1.test_helpers.sensor package — Argus-Toolbelt 1.0 documentation

# api.sensors.v1.test_helpers.sensor package

## Submodules

## api.sensors.v1.test_helpers.sensor.find_sensors module

`api.sensors.v1.test_helpers.sensor.find_sensors.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/sensors/v1/sensor/search, respond with HTTP 403

`api.sensors.v1.test_helpers.sensor.find_sensors.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/sensors/v1/sensor/search, respond with HTTP 404

`api.sensors.v1.test_helpers.sensor.find_sensors.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/sensors/v1/sensor/search, respond with HTTP 200

`api.sensors.v1.test_helpers.sensor.find_sensors.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/sensors/v1/sensor/search, respond with HTTP 401

## api.sensors.v1.test_helpers.sensor.get_sensor module

`api.sensors.v1.test_helpers.sensor.get_sensor.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/sensors/v1/sensor/w+, respond with HTTP 403

`api.sensors.v1.test_helpers.sensor.get_sensor.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/sensors/v1/sensor/w+, respond with HTTP 404

`api.sensors.v1.test_helpers.sensor.get_sensor.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/sensors/v1/sensor/w+, respond with HTTP 200

`api.sensors.v1.test_helpers.sensor.get_sensor.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/sensors/v1/sensor/w+, respond with HTTP 401

## api.sensors.v1.test_helpers.sensor.get_sensor_comments module

`api.sensors.v1.test_helpers.sensor.get_sensor_comments.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/sensors/v1/sensor/w+/comments, respond with HTTP 403

`api.sensors.v1.test_helpers.sensor.get_sensor_comments.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/sensors/v1/sensor/w+/comments, respond with HTTP 404

`api.sensors.v1.test_helpers.sensor.get_sensor_comments.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/sensors/v1/sensor/w+/comments, respond with HTTP 200

`api.sensors.v1.test_helpers.sensor.get_sensor_comments.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/sensors/v1/sensor/w+/comments, respond with HTTP 401

## api.sensors.v1.test_helpers.sensor.list_sensors module

`api.sensors.v1.test_helpers.sensor.list_sensors.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/sensors/v1/sensor, respond with HTTP 403

`api.sensors.v1.test_helpers.sensor.list_sensors.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/sensors/v1/sensor, respond with HTTP 404

`api.sensors.v1.test_helpers.sensor.list_sensors.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/sensors/v1/sensor, respond with HTTP 200

`api.sensors.v1.test_helpers.sensor.list_sensors.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/sensors/v1/sensor, respond with HTTP 401

## Module contents